==> videomass-2.0.0-py3-none-any.whl: videomass-2.0.0.data/data/share/videomass/README.md <==
# **Videomass** provides a graphical interface for audio and video conversions through FFmpeg. 

* [Videomass on PyPi](https://pypi.org/project/videomass/)
* [GitHub Page](https://github.com/jeanslack/Videomass)
* [Support Page and Documentation](http://jeanslack.github.io/Videomass)
* [Wiki page](https://github.com/jeanslack/Videomass/wiki)
* [Downloads Source Code](https://github.com/jeanslack/Videomass/releases)
* [Installers for Windows and MacOsX](https://sourceforge.net/projects/videomass2/)

## News

- October 2019 v.1.7.0: Added EBU R128 and RMS-based audio normalizations. 
  Added support to VP8, VP9, H.265 and OPUS encoders. See changelog for 
  more details.

- November 2019 v.1.8.0: Now Videomass has embedded youtube-dl to downloads
  video from Youtube and more sites.

## Features

- Multi-Platform, work on Linux, MacOs, Windows, FreeBsd.
- Drag n' Drop with multiple files at once.
- Batch processing.
- Fully customizable presets and profiles.
- Possibility to create your new presets and profiles from scratch.
- Has useful presets to start with.
- Supports all formats and codecs available with FFmpeg.
- Displaying information from streams analyzer.
- Real-time video filters preview.
- Three audio normalization modes: Peak, RMS and EBU R128.
- Audio index from videos selectable to apply normalization.
- Setting duration portions for imported files, filters, export and tests.
- Download multiple URLs from youtube with your settings.
- View video information without downloading it.
- Ability to download videos using the 'format code'.
- Log management.
- Multi language (English and Italian Languages support for now).

## Requirements
   
- Python3  >= 3.5.?
- wxPython4 (phoenix) 
- PyPubSub (https://pypi.org/project/PyPubSub/)
- ffmpeg >= 3.2   
- ffprobe (for multimedia streams analysis)  
- ffplay (for playback)

## Optionals 

- youtube-dl (https://pypi.org/project/youtube_dl/)

==> videomass-2.0.3-py3-none-any.whl: videomass-2.0.3.data/data/share/videomass/README.md <==
# **Videomass** provides a graphical interface for audio and video conversions through FFmpeg.

* [Videomass on PyPi](https://pypi.org/project/videomass/)
* [GitHub Page](https://github.com/jeanslack/Videomass)
* [Support Page and Documentation](http://jeanslack.github.io/Videomass)
* [Wiki page](https://github.com/jeanslack/Videomass/wiki)
* [Downloads Source Code](https://github.com/jeanslack/Videomass/releases)
* [Installers for Windows and MacOsX](https://sourceforge.net/projects/videomass2/)

## Features

- Multi-Platform, work on Linux, MacOs, Windows, FreeBsd.
- Drag n' Drop with multiple files at once.
- Batch processing.
- Fully customizable presets and profiles.
- Possibility to create your new presets and profiles from scratch.
- Has useful presets to start with.
- Supports all formats and codecs available with FFmpeg.
- Displaying information from streams analyzer.
- Real-time video filters preview.
- Three audio normalization modes: Peak, RMS and EBU R128.
- Audio index from videos selectable to apply normalization.
- Setting duration portions for imported files, filters, export and tests.
- Download multiple URLs from YouTube and other sites.
- View video information without downloading it.
- Ability to download videos using the 'format code'.
- Log management.
- Multi language (English and Italian Languages support for now).

## Requirements

- Python3  >= 3.6.9
- wxPython4 (phoenix)
- PyPubSub (https://pypi.org/project/PyPubSub/)
- ffmpeg >= 4.1.4
- ffprobe (for multimedia streams analysis)
- ffplay (for playback)

## Optionals

- youtube-dl (https://pypi.org/project/youtube_dl/)
